FormulaInfo class
FormulaInfo for media-style handling
Constructors
- FormulaInfo({required String formula, bool displayMode = false})
-
const
Properties
- displayMode → bool
-
Display mode (inline or block)
final
- formula → String
-
The LaTeX formula string
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited