onRendererAttached property

void Function(String id, DocumentNode? getDocument())? onRendererAttached
getter/setter pair

Called when a RenderHyperBox is attached to the pipeline.

id is stable for the lifetime of this renderer instance. getDocument returns the current DocumentNode (may be null if no content has been set yet).

Implementation

static void Function(
  String id,
  DocumentNode? Function() getDocument,
)? onRendererAttached;