LayoutCacheDiff class

Difference between two layout cache snapshots

Constructors

LayoutCacheDiff({required Map<String, LayoutChange<Rect>> changedPositions, required Map<String, LayoutChange<Size>> changedSizes, required Map<String, LayoutChange<double>> changedBaselines})

Properties

changedBaselines Map<String, LayoutChange<double>>
final
changedPositions Map<String, LayoutChange<Rect>>
final
changedSizes Map<String, LayoutChange<Size>>
final
hasChanges bool
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalChanges int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited