CachedImage class
Cached image data
Constructors
- CachedImage({Image? image, required ImageLoadState state, String? error})
-
const
Properties
- error → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- image → Image?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → ImageLoadState
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited