CssIndexStats class
Statistics about CSS rule indexing
Constructors
Properties
- averageRulesPerTag → double
-
final
- classRules → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- idRules → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tagRules → int
-
final
- totalRules → int
-
final
- universalRules → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited