HyperKeyframes class
A collection of keyframes that define an animation
Constructors
-
HyperKeyframes({required String name, required List<
HyperKeyframe> keyframes}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
-
keyframes
→ List<
HyperKeyframe> -
final
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
interpolate(
double progress) → HyperKeyframe - Interpolate values at a given progress (0.0 - 1.0)
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override