LayoutCacheDiff class
Difference between two layout cache snapshots
Constructors
-
LayoutCacheDiff({required Map<
String, LayoutChange< changedPositions, required Map<Rect> >String, LayoutChange< changedSizes, required Map<Size> >String, LayoutChange< changedBaselines})double> >
Properties
-
changedBaselines
→ Map<
String, LayoutChange< double> > -
final
-
changedPositions
→ Map<
String, LayoutChange< Rect> > -
final
-
changedSizes
→ Map<
String, LayoutChange< Size> > -
final
- hasChanges → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalChanges → int
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited