LineInfo class
A line of fragments after layout
Constructors
Properties
- baseline ↔ double
-
Baseline position relative to line top
getter/setter pair
- bounds ↔ Rect?
-
Line bounds (set after layout)
getter/setter pair
- characterCount → int
-
Number of characters in this line
no setter
-
fragments
→ List<
Fragment> -
Fragments in this line
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
Maximum height of all fragments
no setter
- isEmpty → bool
-
Check if line is empty
no setter
- isNotEmpty → bool
-
Check if line is not empty
no setter
- leftInset ↔ double
-
Left inset for float elements
getter/setter pair
- rightInset ↔ double
-
Right inset for float elements
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- top ↔ double
-
Top position of the line (y coordinate)
getter/setter pair
- width → double
-
Total width of all fragments
no setter
Methods
-
add(
Fragment fragment) → void - Add a fragment to this line
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited