MediaInfo class
Information about a media element
Constructors
- MediaInfo({required MediaType type, required String src, String? poster, bool autoplay = false, bool loop = false, bool muted = false, bool controls = true, double? width, double? height, String? title, AtomicNode? node})
-
const
- MediaInfo.fromNode(AtomicNode node)
-
Create MediaInfo from an AtomicNode
factory
Properties
- autoplay → bool
-
Whether to autoplay
final
- controls → bool
-
Whether to show controls
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
Explicit height (from attributes or CSS)
final
- isAudio → bool
-
Check if this is an audio element
no setter
- isVideo → bool
-
Check if this is a video element
no setter
- loop → bool
-
Whether to loop
final
- muted → bool
-
Whether to mute
final
- node → AtomicNode?
-
Original node for access to all attributes
final
- poster → String?
-
Poster image for video (optional)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- src → String
-
Source URL
final
- title → String?
-
Alt text / title for accessibility
final
- type → MediaType
-
Media type (audio or video)
final
- width → double?
-
Explicit width (from attributes or CSS)
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited