RubyNode class
Ruby annotation node (for Japanese Furigana)
Constructors
- RubyNode({required String baseText, required String rubyText, ComputedStyle? style})
Properties
-
attributes
→ Map<
String, String> -
HTML attributes (id, class, etc.)
finalinherited
- baseText → String
-
Base text (Kanji)
final
-
children
→ List<
UDTNode> -
Child nodes
finalinherited
-
classList
→ List<
String> -
Get CSS class list
no setterinherited
- cssId → String?
-
Get CSS ID
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Unique identifier for this node (for hit testing, selection)
finalinherited
- isBlock → bool
-
Check if this node is block-level
no setterinherited
- isInline → bool
-
Check if this node is inline
no setterinherited
- layoutRect ↔ Rect?
-
Layout result - position relative to parent
Set by Layout Engine after performLayout()
getter/setter pairinherited
- parent ↔ UDTNode?
-
Parent node (null for root)
getter/setter pairinherited
- rubyText → String
-
Ruby text (Furigana)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style ↔ ComputedStyle
-
Computed style (resolved from CSS cascade)
getter/setter pairinherited
- tagName → String?
-
Original HTML tag name (if from HTML)
finalinherited
- textContent → String
-
Get all text content recursively
no setteroverride
- type → NodeType
-
Node type
finalinherited
Methods
-
appendChild(
UDTNode child) → void -
Add a child node
inherited
-
findById(
String targetId) → UDTNode? -
Find node by ID
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeChild(
UDTNode child) → bool -
Remove a child node
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
traverse(
void visitor(UDTNode node)) → void -
Traverse the tree (pre-order)
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited