RubyTextWidget class
Widget wrapper for RenderRubyText
This widget creates a LeafRenderObjectWidget that renders Ruby text using custom painting for perfect baseline alignment.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- RenderObjectWidget
- LeafRenderObjectWidget
- RubyTextWidget
- Available extensions
Constructors
- RubyTextWidget({Key? key, required String baseText, required String rubyText, required TextStyle baseStyle})
-
const
Properties
- baseStyle → TextStyle
-
final
- baseText → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- rubyText → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
bounce(
{Duration duration = const Duration(milliseconds: 1000), int? iterationCount}) → Widget -
Available on Widget, provided by the HyperAnimationExtension extension
Apply a bounce animation -
createElement(
) → LeafRenderObjectElement -
RenderObjectWidgets always inflate to a RenderObjectElement subclass.
inherited
-
createRenderObject(
BuildContext context) → RenderRubyText -
Creates an instance of the RenderObject class that this
RenderObjectWidget represents, using the configuration described by this
RenderObjectWidget.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
didUnmountRenderObject(
covariant RenderObject renderObject) → void -
This method is called when a RenderObject that was previously
associated with this widget is removed from the render tree.
The provided RenderObject will be of the same type as the one created by
this widget's createRenderObject method.
inherited
-
fadeIn(
{Duration duration = const Duration(milliseconds: 300), Duration delay = Duration.zero, Curve curve = Curves.ease}) → Widget -
Available on Widget, provided by the HyperAnimationExtension extension
Apply a fade in animation -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pulse(
{Duration duration = const Duration(milliseconds: 1000), int? iterationCount}) → Widget -
Available on Widget, provided by the HyperAnimationExtension extension
Apply a pulse animation -
slideInLeft(
{Duration duration = const Duration(milliseconds: 300), Duration delay = Duration.zero, Curve curve = Curves.ease}) → Widget -
Available on Widget, provided by the HyperAnimationExtension extension
Apply a slide in from left animation -
spin(
{Duration duration = const Duration(milliseconds: 1000), int? iterationCount}) → Widget -
Available on Widget, provided by the HyperAnimationExtension extension
Apply a spin animation -
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
updateRenderObject(
BuildContext context, covariant RenderRubyText renderObject) → void -
Copies the configuration described by this RenderObjectWidget to the
given RenderObject, which will be of the same type as returned by this
object's createRenderObject.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited